@@ -2,7 +2,7 @@
 Cucumber result to Jira Xray Test repository
 
 """
-__version__ = "0.5.9"
+__version__ = "0.5.10"
 
 
 import datetime
@@ -104,7 +104,7 @@ class CuJiraX:
                 'test_execution': str(ticket_te),
                 'testexecution_name': testexecution_name,
                 'test_plan': self.result_info.testPlanKey,
-                'tests': tests,
+                'existing_tests': tests,
                 'test_environments': self.result_info.testEnvironments
             })
 
@@ -170,6 +170,8 @@ class CuJiraX:
         
         for el in elements:
             test_name = cls.scenarioid_to_tescasename(el.id, el.keyword)
+            logger.info("searching_test_name: " + test_name)
+
             tests = j.get_tests(test_name)
 
             if tests and not ignore_duplicate:
@@ -177,8 +179,7 @@ class CuJiraX:
                     logger.error(test_name)
                     logger.error(["{}".format(t) for t in tests])
                     raise ValueError("More than 1 test key detected: ", tests, test_name)
-            logger.info("search test case: " + test_name)
-            logger.info(tests)
+            logger.info("found_in_jira: " + str(tests))
             found.append(el) if j.get_tests(test_name) else not_found.append(el)
         
         # check duplicate for new test
